import { d as defineComponent, o as openBlock, y as createBlock, z as withCtx, k as createVNode, j as unref, bV as script } from "./index-Hblmz8kc.js";
import { _ as _sfc_main$1 } from "./BaseViewTemplate-BIdYJv-L.js";
const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "DesktopStartView",
  setup(__props) {
    return (_ctx, _cache) => {
      return openBlock(), createBlock(_sfc_main$1, { dark: "" }, {
        default: withCtx(() => [
          createVNode(unref(script), { class: "m-8 w-48 h-48" })
        ]),
        _: 1
      });
    };
  }
});
export {
  _sfc_main as default
};
//# sourceMappingURL=DesktopStartView-B36WWhTC.js.map
